searchData={"items":[{"type":"module","title":"HipcallDeepgram","doc":"Provides API wrappers for Deepgram API\n\nSee https://developers.deepgram.com/reference/deepgram-api-overview for further info on REST endpoints","ref":"HipcallDeepgram.html"},{"type":"function","title":"HipcallDeepgram.listen/3","doc":"Listen endpoint\n\nFor more information https://developers.deepgram.com/reference/listen-file","ref":"HipcallDeepgram.html#listen/3"},{"type":"function","title":"Examples - HipcallDeepgram.listen/3","doc":"iex> audio_url = \"https://static.deepgram.com/examples/Bueller-Life-moves-pretty-fast.wav\"\n    iex> option = [model: \"base\", language: \"tr\"]\n    iex> HipcallDeepgram.listen(audio_url, option)","ref":"HipcallDeepgram.html#listen/3-examples"},{"type":"function","title":"Arguments - HipcallDeepgram.listen/3","doc":"- `audio_url`\n- `options`\n- `config`","ref":"HipcallDeepgram.html#listen/3-arguments"},{"type":"function","title":"Options - HipcallDeepgram.listen/3","doc":"* `:model` - AI model used to process submitted audio. Default: nova-2-general.\n  Learn more https://developers.deepgram.com/docs/model The default value is `\"nova-2-general\"`.\n\n* `:language` - The BCP-47 language tag that hints at the primary spoken language. Default: en.\n  Learn more https://developers.deepgram.com/docs/language The default value is `\"en\"`.\n\n* `:punctuate` (`t:boolean/0`) - Add punctuation and capitalization to the transcript. Default: false.\n  Learn more https://developers.deepgram.com/docs/punctuation The default value is `false`.\n\n* `:diarize` (`t:boolean/0`) - Recognize speaker changes. Each word in the transcript will be assigned a speaker number starting at 0. Default: false.\n  Learn more https://developers.deepgram.com/docs/diarization The default value is `false`.\n\n* `:paragraphs` (`t:boolean/0`) - Split audio into paragraphs. Default: false.\n  Learn more https://developers.deepgram.com/docs/paragraphs The default value is `false`.\n\n* `:smart_format` (`t:boolean/0`) - Apply formatting to transcript output. When set to true, additional formatting will be applied to transcripts to improve readability. Default: false.\n  Learn more https://developers.deepgram.com/docs/smart-format The default value is `false`.\n\n* `:multichannel` (`t:boolean/0`) - Transcribe each audio channel independently. Default: false.\n  Learn more https://developers.deepgram.com/docs/multichannel The default value is `false`.","ref":"HipcallDeepgram.html#listen/3-options"},{"type":"function","title":"Raises - HipcallDeepgram.listen/3","doc":"- `NimbleOptions.ValidationError` - Validates the given options with\nthe given schema and raises if they're not valid.","ref":"HipcallDeepgram.html#listen/3-raises"},{"type":"function","title":"Returns - HipcallDeepgram.listen/3","doc":"- {:ok, Finch.Response.t()}\n- {:error, Exception.t()}","ref":"HipcallDeepgram.html#listen/3-returns"},{"type":"module","title":"HipcallDeepgram.Config","doc":"Reads configuration on application start, parses all environment variables (if any)\nand caches the final config in memory to avoid parsing on each read afterwards.","ref":"HipcallDeepgram.Config.html"},{"type":"function","title":"HipcallDeepgram.Config.api_key/0","doc":"","ref":"HipcallDeepgram.Config.html#api_key/0"},{"type":"function","title":"HipcallDeepgram.Config.api_url/0","doc":"","ref":"HipcallDeepgram.Config.html#api_url/0"},{"type":"extras","title":"HipcallDeepgram","doc":"# HipcallDeepgram\n\nUnofficial Deepgram API Wrapper written in Elixir.","ref":"readme.html"},{"type":"extras","title":"Installation - HipcallDeepgram","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `hipcall_deepgram` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:hipcall_deepgram, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - HipcallDeepgram","doc":"You can configure HipcallDeepgram in your mix config.exs (default $project_root/config/config.exs). \nIf you're using Phoenix add the configuration in your config/dev.exs|test.exs|prod.exs files. \nAn example config is:\n\n```elixir\nimport Config\n\nconfig :hipcall_deepgram,\n  api_key: \"your-api-key\",\n  # optional, useful if you want to do local integration tests using Bypass or similar\n  # (https://github.com/PSPDFKit-labs/bypass), do not use it for production code,\n  # but only in your test config!\n  api_url: \"https://api.deepgram.com/v1/\"\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Configuration override - HipcallDeepgram","doc":"Client library configuration can be overwritten in runtime by passing a %HipcallDeepgram.Config{} \nstruct as last argument of the function you need to use. For instance if you need to use a different \napi_key you can simply do:\n\n```elixir\nconfig_override = %HipcallDeepgram.Config{api_key: \"f3034ef489524e48207d7f4b61ab1f0899e852fd\"}\n# pass the overriden configuration as last argument of the function\nHipcallDeepgram.listen(audio_url, option, config)\n```","ref":"readme.html#configuration-override"},{"type":"extras","title":"Usage overview - HipcallDeepgram","doc":"#","ref":"readme.html#usage-overview"},{"type":"extras","title":"listen endpoint - HipcallDeepgram","doc":"```elixir\niex> audio_url = \"https://static.deepgram.com/examples/Bueller-Life-moves-pretty-fast.wav\"\niex> option = [model: \"base\", language: \"tr\", punctuate: true, diarize: true, paragraphs: true, smart_format: true]\niex> HipcallDeepgram.listen(audio_url, option)\n```","ref":"readme.html#listen-endpoint"},{"type":"extras","title":"Hipcall - HipcallDeepgram","doc":"All [Hipcall](https://www.hipcall.com/en-gb/) libraries:\n\n- [HipcallDisposableEmail](https://github.com/hipcall/hipcall_disposable_email) - Simple library checking the email's domain is disposable or not.\n- [HipcallDeepgram](https://github.com/hipcall/hipcall_deepgram) - Unofficial Deepgram API Wrapper written in Elixir.","ref":"readme.html#hipcall"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.3.0 - Changelog","doc":"- Fix docs problem with adding docs() method.\n- Add [Dependabot](https://github.com/dependabot)\n- Add multichannel feature\n- Update Finch version.","ref":"changelog.html#v0-3-0"},{"type":"extras","title":"v0.2.0 (2024-01-05) - Changelog","doc":"- Add `ci.yml` for CI.\n- Add `smart_format`, `punctuate`, `paragraphs`, `diarize` options to listen endpoint.\n- Improve docs.","ref":"changelog.html#v0-2-0-2024-01-05"},{"type":"extras","title":"v0.1.0 (2024-01-04) - Changelog","doc":"- First release.","ref":"changelog.html#v0-1-0-2024-01-04"},{"type":"extras","title":"LICENSE","doc":"Copyright 2024 [Hipcall LTD](https://www.hipcall.com/en-gb/)\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"content_type":"text/markdown"}